==> apache-camel-4.0.1-src.zip: apache-camel-4.0.1/components/camel-http/src/test/java/org/apache/camel/component/http/handler/ProxyAuthenticationValidationHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.http.handler;

import java.io.IOException;

import org.apache.hc.core5.http.ClassicHttpRequest;
import org.apache.hc.core5.http.ClassicHttpResponse;
import org.apache.hc.core5.http.HttpException;
import org.apache.hc.core5.http.HttpStatus;
import org.apache.hc.core5.http.protocol.HttpContext;

public class ProxyAuthenticationValidationHandler extends BasicValidationHandler {

    protected String user;
    protected String password;

    public ProxyAuthenticationValidationHandler(String expectedMethod,
                                                String expectedQuery, Object expectedContent,
                                                String responseContent, String user, String password) {
        super(expectedMethod, expectedQuery, expectedContent, responseContent);
        this.user = user;
        this.password = password;
    }

    @Override
    public void handle(
            final ClassicHttpRequest request, final ClassicHttpResponse response,
            final HttpContext context)
            throws HttpException, IOException {

        if (!getExpectedCredential().equals(context.getAttribute("proxy-creds"))) {
            response.setCode(HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED);
            return;
        }

        super.handle(request, response, context);
    }

    private String getExpectedCredential() {
        return user + ":" + password;
    }

}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/components/camel-http/src/test/java/org/apache/camel/component/http/handler/ProxyAuthenticationValidationHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.http.handler;

import java.io.IOException;

import org.apache.hc.core5.http.ClassicHttpRequest;
import org.apache.hc.core5.http.ClassicHttpResponse;
import org.apache.hc.core5.http.HttpException;
import org.apache.hc.core5.http.HttpStatus;
import org.apache.hc.core5.http.protocol.HttpContext;

public class ProxyAuthenticationValidationHandler extends BasicValidationHandler {

    protected final String user;
    protected final String password;

    public ProxyAuthenticationValidationHandler(String expectedMethod,
                                                String expectedQuery, Object expectedContent,
                                                String responseContent, String user, String password) {
        super(expectedMethod, expectedQuery, expectedContent, responseContent);
        this.user = user;
        this.password = password;
    }

    @Override
    public void handle(
            final ClassicHttpRequest request, final ClassicHttpResponse response,
            final HttpContext context)
            throws HttpException, IOException {

        if (!getExpectedCredential().equals(context.getAttribute("proxy-creds"))) {
            response.setCode(HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED);
            return;
        }

        super.handle(request, response, context);
    }

    private String getExpectedCredential() {
        return user + ":" + password;
    }

}
